==> mathtext-2.0.1-py3-none-any.whl: mathtext/utils/default_values.py <==
APPROVED_RESPONSE_CASES = [
    ["yes", "answer", ["yes", "t"]],
    ["y", "answer", ["yes", "t"]],
    ["yah", "answer", ["yes", "t"]],
    ["yeah", "answer", ["yes", "t"]],
    ["ok", "answer", ["yes", "t"]],
    ["okay", "answer", ["yes", "t"]],
    ["okey", "answer", ["yes", "t"]],
    ["yea", "answer", ["yes", "t"]],
    ["yh", "answer", ["yes", "t"]],
    ["ys", "answer", ["yes", "t"]],
    ["yrs", "answer", ["yes", "t"]],
    ["yes.", "answer", ["yes", "t"]],
    ["yep", "answer", ["yes", "t"]],
    ["yee", "answer", ["yes", "t"]],
    ["yed", "answer", ["yes", "t"]],
    ["yesh", "answer", ["yes", "t"]],
    ["yew", "answer", ["yes", "t"]],
    ["yex", "answer", ["yes", "t"]],
    ["yey", "answer", ["yes", "t"]],
    ["yez", "answer", ["yes", "t"]],
    ["ready", "answer", ["yes"]],
    ["proceed", "answer", ["yes"]],
    ["continue", "answer", ["yes"]],
    ["t", "answer", ["yes", "t"]],
    ["true", "answer", ["yes", "t"]],
    # ["1", "answer", ["yes", "t"]],
    ["no", "answer", ["no", "f"]],
    ["n", "answer", ["no", "f"]],
    ["nah", "answer", ["no", "f"]],
    ["f", "answer", ["no", "f"]],
    ["false", "answer", ["no", "f"]],
    # ["0", "answer", ["no", "f"]],
    ["even", "answer", ["even"]],
    ["odd", "answer", ["odd"]],
    ["monday", "answer", ["monday"]],
    ["tuesday", "answer", ["tuesday"]],
    ["wednesday", "answer", ["wednesday"]],
    ["thursday", "answer", ["thursday"]],
    ["friday", "answer", ["friday"]],
    ["saturday", "answer", ["saturday"]],
    ["sunday", "answer", ["sunday"]],
    ["mon", "answer", ["monday"]],
    ["tues", "answer", ["tuesday"]],
    ["wed", "answer", ["wednesday"]],
    ["thurs", "answer", ["thursday"]],
    ["fri", "answer", ["friday"]],
    ["sat", "answer", ["saturday"]],
    ["sun", "answer", ["sunday"]],
    [">", "answer", [">", "g"]],
    ["g", "answer", [">", "g"]],
    ["gt", "answer", [">", "g"]],
    ["greater", "answer", [">", "g"]],
    ["greater than", "answer", [">", "g"]],
    ["<", "answer", ["<", "l"]],
    ["l", "answer", ["<", "l"]],
    ["lt", "answer", ["<", "l"]],
    ["less", "answer", ["<", "l"]],
    ["less than", "answer", ["<", "l"]],
    [">=", "answer", [">=", "gte"]],
    ["gte", "answer", [">=", "gte"]],
    ["greater than or equal", "answer", [">=", "gte"]],
    ["<=", "answer", ["<=", "lte"]],
    ["lte", "answer", ["<=", "lte"]],
    ["less than or equal", "answer", ["<=", "lte"]],
    ["=", "answer", ["=", "e"]],
    ["e", "answer", ["=", "e"]],
    ["equal", "answer", ["=", "e"]],
    ["same", "answer", ["=", "e"]],
    ["a", "answer", ["a"]],
    ["b", "answer", ["b"]],
    ["c", "answer", ["c"]],
    ["d", "answer", ["d"]],
    # ['hint', 'keyword', 'hint'],
    ["next", "keyword", "next"],
    ["stop", "keyword", "stop"],
    ["help", "keyword", "help"],
    ["support", "keyword", "support"],
    ["menu", "keyword", "menu"],
    # These keywords below may not be very useful
    ["manu", "keyword", "menu"],
    ["menue", "keyword", "menu"],
    ["meun", "keyword", "menu"],
    ["menus", "keyword", "menu"],
    # ['hints', 'keyword', 'hint'],
    # ['hin', 'keyword', 'hint'],
    ["stp", "keyword", "stop"],
    ["yws", "answer", "yes"],
    ["nest", "keyword", "next"],
    ["nex", "keyword", "next"],
    ["dtop", "keyword", "stop"],
]

PROFANITY_LOOKUP = [
    "anal",
    "anus",
    "arse",
    "ass",
    "asshole",
    "ballsack",
    "balls",
    "bastard",
    "bitch",
    "biatch",
    "bloody",
    "blowjob",
    "blow job",
    "bollock",
    "bollok",
    "boner",
    "boob",
    "bugger",
    "bullshit",
    "bum",
    "butt",
    "buttplug",
    "clitoris",
    "cock",
    "coon",
    "crap",
    "cunt",
    "damn",
    "dick",
    "dildo",
    "dyke",
    "fag",
    "feck",
    "fellate",
    "fellatio",
    "felching",
    "fuck",
    "f u c k",
    "fucking",
    "fudgepacker",
    "fudge packer",
    "flange",
    "Goddamn",
    "God damn",
    "hell",
    "homo",
    "jerk",
    "jizz",
    "knobend",
    "knob end",
    "labia",
    "lmao",
    "lmfao",
    "muff",
    "nigger",
    "nigga",
    "omg",
    "penis",
    "piss",
    "pissed",
    "poop",
    "prick",
    "pube",
    "pussy",
    "queer",
    "scrotum",
    "sex",
    "shit",
    "s hit",
    "sh1t",
    "slut",
    "smegma",
    "spunk",
    "tit",
    "tosser",
    "turd",
    "twat",
    "vagina",
    "wank",
    "whore",
    "wtf",
]


APPROVED_RESPONSES_BY_TYPE = {}
KEYWORD_LOOKUP = {}
TEXT_ANSWER_LOOKUP = {}
for entry in APPROVED_RESPONSE_CASES:
    APPROVED_RESPONSES_BY_TYPE[entry[0]] = entry[1]
    if entry[1] == "answer":
        TEXT_ANSWER_LOOKUP[entry[0]] = entry[2]
    else:
        KEYWORD_LOOKUP[entry[0]] = entry[2]


NUMBER_MAP = {
    "one": 1,
    "two": 2,
    "three": 3,
    "four": 4,
    "five": 5,
    "six": 6,
    "seven": 7,
    "eight": 8,
    "nine": 9,
    "ten": 10,
    "eleven": 11,
    "twelve": 12,
    "thirteen": 13,
    "fourteen": 14,
    "fifteen": 15,
    "sixteen": 16,
    "seventeen": 17,
    "eighteen": 18,
    "nineteen": 19,
    "twenty": 20,
    "thirty": 30,
    "forty": 40,
    "fourty": 40,
    "fifty": 50,
    "sixty": 60,
    "seventy": 70,
    "eighty": 80,
    "ninety": 90,
    "hundred": 100,
    "thousand": 1000,
    "million": 1000000,
    "billion": 1000000000,
    "trillion": 1000000000000,
}


OLD_BUTTONS_LOOKUP = [
    "Yes 🥱",
    "No 🤖",
    "Yes 👌🏿",
    "No 😕",
    "Yes 😏",
    "No 😫",
    "@button_message",
    "@button_message_1",
    "@button_message_2",
    "Continue",
]

==> mathtext-2.0.3-py3-none-any.whl: mathtext/utils/default_values.py <==
APPROVED_RESPONSE_CASES = [
    ["yes", "answer", ["yes", "t"]],
    ["y", "answer", ["yes", "t"]],
    ["yah", "answer", ["yes", "t"]],
    ["yeah", "answer", ["yes", "t"]],
    ["ok", "answer", ["yes", "t"]],
    ["okay", "answer", ["yes", "t"]],
    ["okey", "answer", ["yes", "t"]],
    ["yea", "answer", ["yes", "t"]],
    ["yh", "answer", ["yes", "t"]],
    ["ys", "answer", ["yes", "t"]],
    ["yrs", "answer", ["yes", "t"]],
    ["yes.", "answer", ["yes", "t"]],
    ["yep", "answer", ["yes", "t"]],
    ["yee", "answer", ["yes", "t"]],
    ["yed", "answer", ["yes", "t"]],
    ["yesh", "answer", ["yes", "t"]],
    ["yew", "answer", ["yes", "t"]],
    ["yex", "answer", ["yes", "t"]],
    ["yey", "answer", ["yes", "t"]],
    ["yez", "answer", ["yes", "t"]],
    ["ready", "answer", ["yes"]],
    ["proceed", "answer", ["yes"]],
    ["continue", "answer", ["yes"]],
    ["t", "answer", ["yes", "t"]],
    ["true", "answer", ["yes", "t"]],
    # ["1", "answer", ["yes", "t"]],
    ["no", "answer", ["no", "f"]],
    ["n", "answer", ["no", "f"]],
    ["nah", "answer", ["no", "f"]],
    ["f", "answer", ["no", "f"]],
    ["false", "answer", ["no", "f"]],
    # ["0", "answer", ["no", "f"]],
    ["even", "answer", ["even"]],
    ["odd", "answer", ["odd"]],
    ["monday", "answer", ["monday"]],
    ["tuesday", "answer", ["tuesday"]],
    ["wednesday", "answer", ["wednesday"]],
    ["thursday", "answer", ["thursday"]],
    ["friday", "answer", ["friday"]],
    ["saturday", "answer", ["saturday"]],
    ["sunday", "answer", ["sunday"]],
    ["mon", "answer", ["monday"]],
    ["tues", "answer", ["tuesday"]],
    ["wed", "answer", ["wednesday"]],
    ["thurs", "answer", ["thursday"]],
    ["fri", "answer", ["friday"]],
    ["sat", "answer", ["saturday"]],
    ["sun", "answer", ["sunday"]],
    [">", "answer", [">", "g"]],
    ["g", "answer", [">", "g"]],
    ["gt", "answer", [">", "g"]],
    ["greater", "answer", [">", "g"]],
    ["greater than", "answer", [">", "g"]],
    ["<", "answer", ["<", "l"]],
    ["l", "answer", ["<", "l"]],
    ["lt", "answer", ["<", "l"]],
    ["less", "answer", ["<", "l"]],
    ["less than", "answer", ["<", "l"]],
    [">=", "answer", [">=", "gte"]],
    ["gte", "answer", [">=", "gte"]],
    ["greater than or equal", "answer", [">=", "gte"]],
    ["<=", "answer", ["<=", "lte"]],
    ["lte", "answer", ["<=", "lte"]],
    ["less than or equal", "answer", ["<=", "lte"]],
    ["=", "answer", ["=", "e"]],
    ["e", "answer", ["=", "e"]],
    ["equal", "answer", ["=", "e"]],
    ["same", "answer", ["=", "e"]],
    ["a", "answer", ["a"]],
    ["b", "answer", ["b"]],
    ["c", "answer", ["c"]],
    ["d", "answer", ["d"]],
    # ['hint', 'keyword', 'hint'],
    # ["next", "keyword", "next"],
    ["stop", "keyword", "stop"],
    ["help", "keyword", "help"],
    ["support", "keyword", "support"],
    ["menu", "keyword", "menu"],
    # These keywords below may not be very useful
    ["manu", "keyword", "menu"],
    ["menue", "keyword", "menu"],
    ["meun", "keyword", "menu"],
    ["menus", "keyword", "menu"],
    # ['hints', 'keyword', 'hint'],
    # ['hin', 'keyword', 'hint'],
    ["stp", "keyword", "stop"],
    ["yws", "answer", "yes"],
    # ["nest", "keyword", "next"],
    # ["nex", "keyword", "next"],
    ["dtop", "keyword", "stop"],
]

PROFANITY_LOOKUP = [
    "anal",
    "anus",
    "arse",
    "ass",
    "asshole",
    "ballsack",
    "balls",
    "bastard",
    "bitch",
    "biatch",
    "bloody",
    "blowjob",
    "blow job",
    "bollock",
    "bollok",
    "boner",
    "boob",
    "bugger",
    "bullshit",
    "bum",
    "butt",
    "buttplug",
    "clitoris",
    "cock",
    "coon",
    "crap",
    "cunt",
    "damn",
    "dick",
    "dildo",
    "dyke",
    "fag",
    "feck",
    "fellate",
    "fellatio",
    "felching",
    "fuck",
    "f u c k",
    "fucking",
    "fudgepacker",
    "fudge packer",
    "flange",
    "Goddamn",
    "God damn",
    "hell",
    "homo",
    "jerk",
    "jizz",
    "knobend",
    "knob end",
    "labia",
    "lmao",
    "lmfao",
    "muff",
    "nigger",
    "nigga",
    "omg",
    "penis",
    "piss",
    "pissed",
    "poop",
    "prick",
    "pube",
    "pussy",
    "queer",
    "scrotum",
    "sex",
    "shit",
    "s hit",
    "sh1t",
    "slut",
    "smegma",
    "spunk",
    "tit",
    "tosser",
    "turd",
    "twat",
    "vagina",
    "wank",
    "whore",
    "wtf",
]


APPROVED_RESPONSES_BY_TYPE = {}
KEYWORD_LOOKUP = {}
TEXT_ANSWER_LOOKUP = {}
for entry in APPROVED_RESPONSE_CASES:
    APPROVED_RESPONSES_BY_TYPE[entry[0]] = entry[1]
    if entry[1] == "answer":
        TEXT_ANSWER_LOOKUP[entry[0]] = entry[2]
    else:
        KEYWORD_LOOKUP[entry[0]] = entry[2]


NUMBER_MAP = {
    "one": 1,
    "two": 2,
    "three": 3,
    "four": 4,
    "five": 5,
    "six": 6,
    "seven": 7,
    "eight": 8,
    "nine": 9,
    "ten": 10,
    "eleven": 11,
    "twelve": 12,
    "thirteen": 13,
    "fourteen": 14,
    "fifteen": 15,
    "sixteen": 16,
    "seventeen": 17,
    "eighteen": 18,
    "nineteen": 19,
    "twenty": 20,
    "thirty": 30,
    "forty": 40,
    "fourty": 40,
    "fifty": 50,
    "sixty": 60,
    "seventy": 70,
    "eighty": 80,
    "ninety": 90,
    "hundred": 100,
    "thousand": 1000,
    "million": 1000000,
    "billion": 1000000000,
    "trillion": 1000000000000,
}


OLD_BUTTONS_LOOKUP = [
    "Yes 🥱",
    "No 🤖",
    "Yes 👌🏿",
    "No 😕",
    "Yes 😏",
    "No 😫",
    "@button_message",
    "@button_message_1",
    "@button_message_2",
    "Continue",
]
